/*
	$Id$

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib;

/**
	Utility class for logging use of deprecated taglib attributes.
	This will normally not show up at compile time since it is
	Tomcat that converts the JSP to an executable java class.

	@since 3.3.2
	@author Nicklas
*/
public class DeprecationLogger 
{

	private static final org.slf4j.Logger log = 
			org.slf4j.LoggerFactory.getLogger(DeprecationLogger.class);

	/**
		Log a warning for using the given taglib and attribute. 
		'removedIn' can be set to the BASE version when the attribute
		will be removed.
	 */
	public static void warn(String taglib, String attribute, String removedIn)
	{
		String msg = "Use of deprecated tag attribute "+taglib + "/" + attribute;
		if (removedIn != null)
		{
			msg += ", scheduled for removal in BASE "+removedIn;
		}
		log.warn(msg, new Throwable());
	}
}
