/**
	$Id: DerivedBioAssayData.java 6996 2015-11-03 10:32:22Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2015-11-03 11:32:22 +0100 (ti, 03 nov 2015) $
	@hibernate.class table="`DerivedBioAssays`" lazy="true"
	@see <a href="../../../../../../html/developer/api/data_api.bioassays.html">Developer documentation: Bioassays and raw data</a>
*/
public class DerivedBioAssayData
	extends AnnotatedData
	implements RegisteredData, FileStoreEnabledData, SubtypableData
{

	public DerivedBioAssayData()
	{}
	
	/*
		From the SubtypableData interface
		----------------------------------
	*/
	private ItemSubtypeData subtype;
	@Override
	public ItemSubtypeData getItemSubtype()
	{
	   return subtype;
	}
	@Override
	public void setItemSubtype(ItemSubtypeData subtype)
	{
	   this.subtype = subtype;
	}
	// ------------------------------

	/*
		From the FileStoreEnabledData interface
		-------------------------------------------
	*/
	private FileSetData fileSet;
	@Override
	public FileSetData getFileSet()
	{
	   return fileSet;
	}
	@Override
	public void setFileSet(FileSetData fileSet)
	{
	   this.fileSet = fileSet;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private boolean isRoot;
	/**
		A flag indicating if this is a root derived bioassay or not. A root
		bioassay can only have physical bioassays as parents, while a non-root 
		bioassay only can have other derived bioassays as parents (but the
		physical bioassays collection should be automatically managed to reflect
		the parents of the parents, etc.)
		@since 3.2
		@hibernate.property column="`is_root`" type="boolean" not-null="true" 
	*/
	public boolean isRoot()
	{
		return isRoot;
	}
	public void setRoot(boolean isRoot)
	{
		this.isRoot = isRoot;
	}
	
	private Set<PhysicalBioAssayData> physicalBioAssays;
	/**
		A set that manages the parent physical bioassays that this derived bioassay
		is related to.
		@since 3.2
		@hibernate.set table="`ParentPhysicalBioAssays`" lazy="true"
		@hibernate.collection-key column="`derivedbioassay_id`"
		@hibernate.collection-many-to-many column="`physicalbioassay_id`" class="net.sf.basedb.core.data.PhysicalBioAssayData"
	*/
	public Set<PhysicalBioAssayData> getPhysicalBioAssays()
	{
		if (physicalBioAssays == null) physicalBioAssays = new HashSet<PhysicalBioAssayData>();
		return physicalBioAssays;
	}
	
	void setPhysicalBioAssays(Set<PhysicalBioAssayData> physicalBioAssays)
	{
		this.physicalBioAssays = physicalBioAssays;
	}
	
	private Set<DerivedBioAssayData> parents;
	/**
		A set that manages the parent bioassays that this derived bioassay
		related to.
		@since 3.2
		@hibernate.set table="`ParentDerivedBioAssays`" lazy="true"
		@hibernate.collection-key column="`derivedbioassay_id`"
		@hibernate.collection-many-to-many column="`parentbioassay_id`" class="net.sf.basedb.core.data.DerivedBioAssayData"
	*/
	public Set<DerivedBioAssayData> getParents()
	{
		if (parents == null) parents = new HashSet<DerivedBioAssayData>();
		return parents;
	}
	void setParents(Set<DerivedBioAssayData> parents)
	{
		this.parents = parents;
	}

	private Set<DerivedBioAssayData> children;
	/**
		This is the inverse end.
		@see DerivedBioAssayData#getParents()
		@hibernate.set table="`ParentDerivedBioAssays`" lazy="true" inverse="true" 
		@hibernate.collection-key column="`parentbioassay_id`"
		@hibernate.collection-many-to-many column="`derivedbioassay_id`" class="net.sf.basedb.core.data.DerivedBioAssayData"
	*/
	public Set<DerivedBioAssayData> getChildren()
	{
		return children;
	}
	void setChildren(Set<DerivedBioAssayData> children)
	{
		this.children = children;
	}

	private Set<RawBioAssayData> rawBioAssays;
	/**
		This is the inverse end.
		@see RawBioAssayData#getParentBioAssay()
		@hibernate.set lazy="true" inverse="true" 
		@hibernate.collection-key column="`bioassay_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.RawBioAssayData"
	*/
	Set<RawBioAssayData> getRawBioAssays()
	{
		return rawBioAssays;
	}
	void setRawBioAssays(Set<RawBioAssayData> rawBioAssays)
	{
		this.rawBioAssays = rawBioAssays;
	}

	
	private ProtocolData protocol;
	/**
		Get the protocol used to create this bioassay set.
		@hibernate.many-to-one column="`protocol_id`" not-null="false" outer-join="false"
	*/
	public ProtocolData getProtocol()
	{
		return protocol;
	}
	public void setProtocol(ProtocolData protocol)
	{
		this.protocol = protocol;
	}

	private KitData kit;
	/**
		Get the kit used to create this bioassay set.
		@since 3.7
		@hibernate.many-to-one column="`kit_id`" not-null="false" outer-join="false"
	*/
	public KitData getKit()
	{
		return kit;
	}
	public void setKit(KitData kit)
	{
		this.kit = kit;
	}
	
	private HardwareData hardware;
	/**
	 	Get the hardware used to create this bioassay set.
	 	@hibernate.many-to-one column="`hardware_id`" not-null="false" outer-join="false"
	*/
	public HardwareData getHardware()
	{
		return hardware;
	}
	public void setHardware(HardwareData hardware)
	{
		this.hardware = hardware;
	}

	private SoftwareData software;
	/**
	 	Get the software used to create this bioassay set.
	 	@hibernate.many-to-one column="`software_id`" not-null="false" outer-join="false"
	*/
	public SoftwareData getSoftware()
	{
		return software;
	}
	public void setSoftware(SoftwareData software)
	{
		this.software = software;
	}

	private JobData job;
	/**
	 	Get the job used to create this bioassay set.
	 	@hibernate.many-to-one column="`job_id`" not-null="false" update="false" outer-join="false"
	*/
	public JobData getJob()
	{
		return job;
	}
	public void setJob(JobData job)
	{
		this.job = job;
	}

	private ExtractData extract;
	/**
	 	Get the extract that this bioassay is related to.
	 	@hibernate.many-to-one column="`extract_id`" not-null="false" outer-join="false"
	*/
	public ExtractData getExtract()
	{
		return extract;
	}
	public void setExtract(ExtractData extract)
	{
		this.extract = extract;
	}
	
}
