/*
	$Id: ResultIterator.java 7551 2018-12-12 14:41:10Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Iterator;

/**
	Return the result of a query as an iterator. An iterator doesn't load
	the entire dataset into memory at once, it waits until the client application
	request the next row. This interface is useful for all types of queries and
	mostly for queries that might return a large number of items.
	<p>
	Implementors should not allow modifications to the iterator, ie.
	it is not allowed to call the {@link Iterator#remove()} method.
	
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2018-12-12 15:41:10 +0100 (on, 12 dec 2018) $
*/
public interface ResultIterator<I>
	extends QueryResult, Iterator<I>, AutoCloseable
{
	
	/**
		Close the iterator and immediately release all resources 
		associated with it.
	*/
	@Override
	public void close();
	
	/**
		Check if the iterator has been closed.
	*/
	public boolean isClosed();

}
