/**
	$Id: SignalHandler.java 6432 2014-03-14 07:23:38Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.signal;

import java.util.Collection;

import net.sf.basedb.util.extensions.Action;

/**
	A signal handler is an object that is able to receive and act on signals.
	A specific signal handler instance may only support a subset of all
	registered signals (see {@link Signal#getSignals()}). A signal handler is usually
	created by a {@link SignalTarget}. When the handler receives a signal, it should
	in most cases notify the target about it. How this is done is up to each
	implementation.
	<p>
	Signal handler implementations need to be implemented in a thread safe. Once 
	they have been registered with a {@link SignalReceiver} they may receive 
	multiple signals in different threads at the same time.

	@author nicklas
	@version 2.6
	@base.modified $Date: 2014-03-14 08:23:38 +0100 (fr, 14 mar 2014) $
*/
public interface SignalHandler
	extends Action
{
	/**
		Handle the given signal. It is recommended that signals are handled
		as quickly as possible. If there is a risk that it may take a long time
		it is recommended to spawn a new thread and handle the signal asynchronously.
		@param signal The signal to handle
		@throws UnsupportedSignalException If the signal is not supported
	*/
	public void handleSignal(Signal signal);
	
	/**
		Get all signals that are supported by this handler.
		@return A collection of signals
	*/
	public Collection<Signal> getSupportedSignals();
	
	/**
		Check if a given signal is supported.
		@param signal The signal to check
		@return TRUE if the signal is supported, FALSE otherwise
	*/
	public boolean supports(Signal signal);

}
