/**
	$Id: InputStreamLocator.java 5225 2010-01-29 13:34:03Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.IOException;
import java.io.InputStream;

/**
	Defines a generic interface for opening an input stream from a named
	resource. Implementations should know how to access a given resource
	and create a stream that reads data from the resource.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-29 14:34:03 +0100 (fr, 29 jan 2010) $
*/
public interface InputStreamLocator
{
	
	/**
		Create an input stream that reads data from the given named
		resource.
		@param name The name (for example a file name) of the resource
		@return An input stream
		@throws IOException If there is any problem with locating or opening
			the resource
	*/
	public InputStream getInputStream(String name)
		throws IOException;
	
	/**
		Get the size in bytes of the given named resource.
		@param name The name (for example a file name) of the resouce
		@return The size in bytes, or -1 if not known
	*/
	public long getSize(String name);
}
