/**
	$Id: FactoryParametersKey.java 5606 2011-04-14 07:45:23Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager;

/**
	Key implementation used for configuration parameters for factories.
	This is used for both action, renderer and error handler factories
	registered for extensions and extension points.
	<p>
	
	The parameters are stored as metadata on the extensions file that
	loaded the extensions and can be accessed via 
	{@link ExtensionsFile#getMetadata(ObjectKey)}. The returned value is
	an XML representation of the parameters as they appear in the
	definitions file.
	<p>
	
	The key is the factory instance itself.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-14 09:45:23 +0200 (to, 14 apr 2011) $
*/
public class FactoryParametersKey
	implements ObjectKey<String>
{

	private final Object factory;
	
	/**
		Create a new key for the given factory.
		@param factory The factory (required)
	*/
	public FactoryParametersKey(Object factory)
	{
		if (factory == null) throw new NullPointerException("factory");
		this.factory = factory;
	}
	
	/*
		From the ObjectKey interface
		----------------------------
	*/
	@Override
	public String toDescription()
	{
		return "Factory '" + factory + "'";
	}
	// -----------------------------

	
	/*
		From the Object class
		---------------------
	*/
	@Override
	public int hashCode()
	{
		return factory.hashCode();
	}
	
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj) return true;
		if (obj == null || obj.getClass() != this.getClass()) return false;
		FactoryParametersKey other = (FactoryParametersKey)obj;
		return other.factory.equals(this.factory);
	}
	
	@Override
	public String toString()
	{
		return "FactoryParametersKey@" + System.identityHashCode(this) + "[" + factory + "]";
	}
	// -----------------------

	
	
}
