/*
	$Id: TestProjectKey.java 5689 2011-08-11 09:09:06Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.*;

import java.util.EnumSet;

public class TestProjectKey
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing project key");
		write_header();
		
		// Delete "garbage" from previous tests
		ProjectKey.deleteUnusedProjectKeys();
		
		// Extra test: create project for the key
		int projectId = TestProject.test_create("Test project", true);
		
		// Standard tests: create, load
		int id = test_create(projectId, EnumSet.of(Permission.WRITE));
		test_load(id);

		// Extra tests: create new key with same permission -> id2 == id
		int id2 = test_create(projectId, EnumSet.of(Permission.WRITE));
		write("--id==id2 "+(id==id2 ? "OK" : "FAILED id="+id+"; id2="+id2));
		ok = ok && (id == id2);

		// Extra tests: create new key with different permission -> id3 != id
		int id3 = test_create(projectId, EnumSet.of(Permission.USE));
		write("--id!=id3 "+(id!=id3 ? "OK" : "FAILED id="+id+"; id3="+id3));
		ok = ok && (id != id3);

		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();

		// Standard test: Delete
		TestProject.test_delete(projectId);
		test_delete_unused(2);

		write("++Testing project key "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(int projectId, EnumSet<Permission> permissions)
	{
		if (projectId == 0) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			Project p = Project.getById(dc, projectId);
			ProjectPermissions pp = new ProjectPermissions();
			pp.setPermissions(p, permissions);
			ProjectKey pk = ProjectKey.getNewOrExisting(dc, pp);
			if (!pk.isInDatabase())
			{
				dc.saveItem(pk);
				dc.commit();
			}
			id = pk.getId();
			write_item(0, pk);
			write("--Create project key OK");
		}
		catch (Throwable ex)
		{
			write("--Create project key FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void test_load(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ProjectKey pk = ProjectKey.getById(dc, id);
			write_item(0, pk);
			write("--Load project key OK");
		}
		catch (Throwable ex)
		{
			write("--Load project key FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}
	
	static void test_delete_unused(int expected)
	{
		try
		{
			int numDeleted = ProjectKey.deleteUnusedProjectKeys();
			if (expected >= 0 && numDeleted != expected)
			{
				throw new BaseException("Unexpected number of unused item keys: " + 
					numDeleted + "; expected " + expected);
			}
			write("--Delete unused project keys OK (" + numDeleted + ")");
		}
		catch (Throwable ex)
		{
			write("--Delete unused project keys FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}

	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			write("   \tID");
			write("-- \t--");
		}
	}
	static void write_item(int i, ProjectKey pk)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+pk.getId());
	}
	static void write_item(int i, Project p, EnumSet<Permission> permissions)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+p.getId()+"\t"+p.getName()+"\t"+p.getDescription()+"\t"+permissions);
	}
	static void write(String message)
	{
		System.out.println(message);
	}

}

