/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var FileServers = function()
{
	var fileServers = {};
	
	/**
		Initialize the page.
	*/
	fileServers.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', fileServers.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabValidator('settings.info', fileServers.validateFileServer);
			TabControl.addTabValidator('settings.httpsOptions', fileServers.validateHttpsOptions);
			TabControl.addTabValidator('settings.sshOptions', fileServers.validateSshOptions);
			
			// Connection manager
			Events.addEventHandler('connectionManager', 'change', fileServers.connectionManagerOnChange);
			fileServers.connectionManagerOnChange();
			
			// Certificates
			Events.addEventHandler('removeServerCertificate', 'click', fileServers.removeServerCertificateOnClick);
			Events.addEventHandler('removeClientCertificate', 'click', fileServers.removeClientCertificateOnClick);
			Events.addEventHandler('removeSshPrivateKey', 'click', fileServers.removeSshPrivateKeyOnClick);
			
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'FILESERVER', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'FILESERVER'};
			var tableAttributes = {'table-id': 'servers'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
		
	fileServers.validateFileServer = function()
	{
		var frm = document.forms['server'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		if (frm.rootPath.value)
		{
			if (frm.rootPath.value.indexOf('/') != 0)
			{
				Forms.showNotification(frm.rootPath, 'Path must begin with a /');
				return false;
			}
			if (frm.rootPath.value.lastIndexOf('/') == frm.rootPath.value.length - 1)
			{
				Forms.showNotification(frm.rootPath, 'Path must not end with a /');
				return false;
			}
		}
		return true;
	}
	
	fileServers.validateHttpsOptions = function()
	{
		return true;
	}

	fileServers.validateSshOptions = function()
	{
		var frm = document.forms['server'];
		if (frm.sshFingerprint.value)
		{
			if (!/^[0-9a-f]{2}(\:[0-9a-f]{2}){15}$/.test(frm.sshFingerprint.value) &&
				!/^[a-zA-Z0-9+/]{43}=?$/.test(frm.sshFingerprint.value)	
			)
			{
				Forms.showNotification(frm.sshFingerprint, 'Not a valid MD5 or SHA-256 fingerprint');
				return false;
			}
		}
		return true;
	}
	
	fileServers.save = function()
	{
		var frm = document.forms['server'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	var currentCMF;
	fileServers.connectionManagerOnChange = function()
	{
		var frm = document.forms['server'];
		if (currentCMF) Doc.hide(currentCMF);
		
		var cmfId = frm.connectionManager.value;
		if (!cmfId) cmfId = 'auto';
		currentCMF = 'cmf.' + cmfId + '.description';
		Doc.show(currentCMF);
	}

	fileServers.removeServerCertificateOnClick = function()
	{
		var frm = document.forms['server'];
		if (frm.remove_server_certificate.checked)
		{
			frm.server_certificate.value = '';
			frm.server_certificate.disabled = true;
		}
		else
		{
			frm.server_certificate.disabled = false;
		}
	}
	
	fileServers.removeClientCertificateOnClick = function()
	{
		var frm = document.forms['server'];
		if (frm.remove_client_certificate.checked)
		{
			frm.client_certificate.value = '';
			frm.client_certificate.disabled = true;
			frm.client_certificate_password.disabled = true;
		}
		else
		{
			frm.client_certificate.disabled = false;
			frm.client_certificate_password.disabled = false;
		}
	}

	fileServers.removeSshPrivateKeyOnClick = function()
	{
		var frm = document.forms['server'];
		if (frm.remove_ssh_private_key.checked)
		{
			frm.ssh_private_key.value = '';
			frm.ssh_private_key.disabled = true;
			frm.ssh_private_key_password.disabled = true;
			frm.ssh_private_key_format.disabled = true;
		}
		else
		{
			frm.ssh_private_key.disabled = false;
			frm.ssh_private_key_password.disabled = false;
			frm.ssh_private_key_format.disabled = false;
		}
	}

	return fileServers;
}();

Doc.onLoad(FileServers.initPage);
